[−][src]Enum der_parser::error::BerError
Error for BER/DER parsers
Variants
BerTypeErrorBER object does not have the expected type
BerValueErrorBER object does not have the expected value
InvalidTagInvalidClassInvalidLengthConstructExpectedDER object was expected to be constructed (and found to be primitive)
ConstructUnexpectedDER object was expected to be primitive (and found to be constructed)
IntegerTooLargeBER integer is too large to fit in a native type. Use as_bigint()
BerMaxDepthBER recursive parsing reached maximum depth (See MAX_RECURSION)
ObjectTooShortWhen parsing a defined sequence, some items could not be found
DerConstraintFailedA DER constraint failed (object may be using BER encoding?)
UnknownTagUnsupportedFeature is not yet implemented
Custom(u32)Custom error type left for parsers on top of this crate, so they can handle their custom errors
NomError(ErrorKind)Error raised by the underlying nom parser