[−][src]Module der_parser::der
Distinguished Encoding Rules (DER) objects and parser
All functions in this crate use BER parsing functions (see the ber module)
internally, adding constraints verification where needed.
The objects BerObject and DerObject are the same (type alias): all BER functions,
combinators and macros can be used, and provide additional tools for DER parsing.
Functions
| der_read_element_content | Parse DER object content recursively |
| der_read_element_content_as | Parse the next bytes as the content of a DER object. |
| der_read_element_header | Read an object header (DER) |
| parse_der | Parse DER object recursively |
| parse_der_bitstring | Read an bitstring value |
| parse_der_bmpstring | Read a BmpString value |
| parse_der_bool | Read a boolean value |
| parse_der_content | Parse the next bytes as the content of a DER object (combinator) |
| parse_der_endofcontent | Read end of content marker |
| parse_der_enum | Read an enumerated value |
| parse_der_explicit | Deprecated Parse an optional tagged object, applying function to get content |
| parse_der_explicit_optional | Parse an optional tagged object, applying function to get content |
| parse_der_generalizedtime | Read a Generalized time value |
| parse_der_generalstring | Read a GeneralString value |
| parse_der_graphicstring | Read a GraphicString value |
| parse_der_ia5string | Read an IA5 string value. The content is verified to be ASCII. |
| parse_der_implicit | Parse an implicit tagged object, applying function to read content |
| parse_der_integer | Read an integer value |
| parse_der_null | Read a null value |
| parse_der_numericstring | Read a numeric string value. The content is verified to contain only digits and spaces. |
| parse_der_objectdescriptor | Read a ObjectDescriptor value |
| parse_der_octetstring | Read an octetstring value |
| parse_der_oid | Read an object identifier value |
| parse_der_printablestring | Read a printable string value. The content is verified to contain only the allowed characters. |
| parse_der_recursive | Parse DER object recursively, specifying the maximum recursion depth |
| parse_der_relative_oid | Read a relative object identifier value |
| parse_der_sequence | Parse a sequence of DER elements |
| parse_der_set | Parse a set of DER elements |
| parse_der_t61string | Read a T61 string value |
| parse_der_u32 | Parse DER object and try to decode it as a 32-bits unsigned integer |
| parse_der_u64 | Parse DER object and try to decode it as a 64-bits unsigned integer |
| parse_der_universalstring | Read a UniversalString value |
| parse_der_utctime | Read an UTC time value |
| parse_der_utf8string | Read a UTF-8 string value. The encoding is checked. |
| parse_der_videotexstring | Read a Videotex string value |
| parse_der_with_tag | Parse a DER object, expecting a value with specified tag |
| visiblestring | Read a printable string value. The content is verified to contain only the allowed characters. |
Type Definitions
| DerObject | Representation of a DER-encoded (X.690) object |
| DerTag | DER tag (same as BER tag) |